@@ -1,32 +1,67 @@
+"""
+Functions
+=========
+class shape:
+    def __init__(self, sx=0.0, sy=0.0,
+            x=0.0, y=0.0, ang=0.0, scale=1.0,
+            stroke=1.0, color=0x000000, alpha=1.0, dur=0.0):
+
+class frame:
+    def __init__(self, objs,
+            x=0.0, y=0.0, ang=0.0, scale=1.0,
+            stroke=1.0, color=0x000000, alpha=1.0, dur=0.0):
+
+def animate(objs, filename='ani.svg', x_lim=None, y_lim=None, width=None,
+            progress=False):
+"""
+
 class shape:
     """
     Animation shape class.
 
     Attributes
     ----------
-    x : float or array_like, default 0.0
+    sx : float or array_like, default 0.0
         x values of the shape or the x-axis radius of an ellipse.
-    y : float or array_like, default 0.0
+    sy : float or array_like, default 0.0
         y values of the shape or the y-axis radius of an ellipse.
+    x : float or array_like, default 0.0
+        x-axis translation values of an object.
+    y : float or array_like, default 0.0
+        y-axis translation values of an object.
+    ang : float or array_like, default 0.0
+        Angles of rotation of an object.
+    scale : float or array_like, default 1.0
+        Scaling factors of an object.
     stroke : float or array_like, default 1.0
-        Stroke width or animated widths.
+        Stroke width of an object.
     color : float or array_like, default 0x000000
-        Stroke or fill color or animated colors.  It is a fill color or
-        colors if `stroke` is a scalar zero.
+        Stroke or fill color of an object. It is a fill color if `stroke` is a
+        scalar zero.
     alpha : float or array_like, default 1.0
-        Opacity or animated opacity values.  0.0 means fully transparent and
-        1.0 means fully opaque.
+        Opacity of an object. 0.0 means fully transparent and 1.0 means fully
+        opaque.
     dur : float, default 1.0
         Animation duration in seconds.
     """
 
-    def __init__(self, x=0.0, y=0.0, stroke=1.0, color=0x000000,
-            alpha=1.0, dur=0.0):
+    def __init__(self, sx=0.0, sy=0.0,
+            x=0.0, y=0.0, ang=0.0, scale=1.0,
+            stroke=1.0, color=0x000000, alpha=1.0, dur=0.0):
+
         # Reduce lists of length 1 to scalars.
+        if not isinstance(sx, (float, int)) and len(sx) == 1:
+            sx = sx[0]
+        if not isinstance(sy, (float, int)) and len(sy) == 1:
+            sy = sy[0]
         if not isinstance(x, (float, int)) and len(x) == 1:
             x = x[0]
         if not isinstance(y, (float, int)) and len(y) == 1:
             y = y[0]
+        if not isinstance(ang, (float, int)) and len(ang) == 1:
+            ang = ang[0]
+        if not isinstance(scale, (float, int)) and len(scale) == 1:
+            scale = scale[0]
         if not isinstance(stroke, (float, int)) and len(stroke) == 1:
             stroke = stroke[0]
         if not isinstance(color, (float, int)) and len(color) == 1:
@@ -34,15 +69,31 @@ class shape:
         if not isinstance(alpha, (float, int)) and len(alpha) == 1:
             alpha = alpha[0]
 
-        # Ensure if either x or y is an array, they both are.
-        if isinstance(x, (float, int)) and not isinstance(y, (float, int)):
-            x = [x for n in range(len(y))]
-        elif isinstance(y, (float, int)) and not isinstance(x, (float, int)):
-            y = [y for n in range(len(x))]
+        # Ensure sx and sy are the same lengths.
+        if not isinstance(sx, (float, int)) or \
+                not isinstance(sy, (float, int)):
+            if isinstance(sx, (float, int)):
+                sx = [sx for n in range(len(sy))]
+            if isinstance(sy, (float, int)):
+                sy = [sy for n in range(len(sx))]
+            assert (len(sx) == len(sy))
+
+        # Ensure x and y are the same lengths.
+        if not isinstance(x, (float, int)) or \
+                not isinstance(y, (float, int)):
+            if isinstance(x, (float, int)):
+                x = [x for n in range(len(y))]
+            if isinstance(y, (float, int)):
+                y = [y for n in range(len(x))]
+            assert (len(x) == len(y))
 
         # Add these parameters to the object.
+        self.sx = sx
+        self.sy = sy
         self.x = x
         self.y = y
+        self.ang = ang
+        self.scale = scale
         self.stroke = stroke
         self.color = color
         self.alpha = alpha
@@ -58,19 +109,34 @@ class frame:
     objs : shape or frame or list of such
         A single shape or frame object or a list of such objects.
     x : float or array_like, default 0.0
-        x-axis values of translation of the objects within the frame.
+        x-axis translation values of an object.
     y : float or array_like, default 0.0
-        y-axis values of translation of the objects within the frame.
+        y-axis translation values of an object.
     ang : float or array_like, default 0.0
-        Angles of rotation of the objects within the frame in degrees.
+        Angles of rotation of an object.
     scale : float or array_like, default 1.0
-        Scaling factors of the objects within the frame.
+        Scaling factors of an object.
+    stroke : float or array_like, default 1.0
+        Stroke width of an object.
+    color : float or array_like, default 0x000000
+        Stroke or fill color of an object. It is a fill color if `stroke` is a
+        scalar zero.
+    alpha : float or array_like, default 1.0
+        Opacity of an object. 0.0 means fully transparent and 1.0 means fully
+        opaque.
     dur : float, default 1.0
         Animation duration in seconds.
     """
 
-    def __init__(self, objs, x=0.0, y=0.0, ang=0.0, scale=1.0, dur=0.0):
+    def __init__(self, objs,
+            x=0.0, y=0.0, ang=0.0, scale=1.0,
+            stroke=1.0, color=0x000000, alpha=1.0, dur=0.0):
+
         # Reduce lists of length 1 to scalars.
+        if not isinstance(sx, (float, int)) and len(sx) == 1:
+            sx = sx[0]
+        if not isinstance(sy, (float, int)) and len(sy) == 1:
+            sy = sy[0]
         if not isinstance(x, (float, int)) and len(x) == 1:
             x = x[0]
         if not isinstance(y, (float, int)) and len(y) == 1:
@@ -79,16 +145,25 @@ class frame:
             ang = ang[0]
         if not isinstance(scale, (float, int)) and len(scale) == 1:
             scale = scale[0]
+        if not isinstance(stroke, (float, int)) and len(stroke) == 1:
+            stroke = stroke[0]
+        if not isinstance(color, (float, int)) and len(color) == 1:
+            color = color[0]
+        if not isinstance(alpha, (float, int)) and len(alpha) == 1:
+            alpha = alpha[0]
 
         # Ensure objs is a list.
         if isinstance(objs, (shape, frame)):
             objs = [objs]
 
-        # Ensure if either x or y is an array, they both are.
-        if isinstance(x, (float, int)) and not isinstance(y, (float, int)):
-            x = [x for n in range(len(y))]
-        elif isinstance(y, (float, int)) and not isinstance(x, (float, int)):
-            y = [y for n in range(len(x))]
+        # Ensure x and y are the same lengths.
+        if not isinstance(x, (float, int)) or \
+                not isinstance(y, (float, int)):
+            if isinstance(x, (float, int)):
+                x = [x for n in range(len(y))]
+            if isinstance(y, (float, int)):
+                y = [y for n in range(len(x))]
+            assert (len(x) == len(y))
 
         # Add these parameters to the object.
         self.objs = objs
@@ -96,29 +171,32 @@ class frame:
         self.y = y
         self.ang = ang
         self.scale = scale
+        self.stroke = stroke
+        self.color = color
+        self.alpha = alpha
         self.dur = dur
 
 
-def animate(obj, filename='ani.svg', x_lim=None, y_lim=None, width=None,
+def animate(objs, filename='ani.svg', x_lim=None, y_lim=None, width=None,
             progress=False):
     """
     Create an svg (scalable vector graphics) animation file from the data stored
-    in `obj`.
+    in `objs`.
 
     Parameters
     ----------
-    obj : shape object, frame object, or list of such objects
+    objs : shape object, frame object, or list of such objects
         The data to create an animation.
     filename : string, default 'ani.svg'
-        The desired name of output file.  End it with '.svg' in order for
+        The desired name of output file. End it with '.svg' in order for
         your system to know which application to use to open it.
     x_lim : array_like, default [-1, 1]
         A list of the minimum and maximum x values to display in the animation.
     y_lim : array_like, default [-1, 1]
         A list of the minimum and maximum y values to display in the animation.
     width : float, default 640
-        Desired width of the animation image in pixels.  This is also used in
-        determining the scaling factor for the dimensions of the image.  If not
+        Desired width of the animation image in pixels. This is also used in
+        determining the scaling factor for the dimensions of the image. If not
         specified, the image will actually automatically scale to fit the size
         of the browser window.
     progress : bool, default False
@@ -154,17 +232,10 @@ def animate(obj, filename='ani.svg', x_lim=None, y_lim=None, width=None,
     fid.write('>')
 
     # Crawl through the hierarchy of frames and objects and add them to the
-    # animation.
-    if isinstance(obj, (shape, frame)):
-        obj = [obj]
-    level = 1
-    dur_max = 0.0
-    for child in obj:
-        dur = add_obj(fid, child, level, p_scale)
-        if dur > dur_max:
-            dur_max = dur
+    # animation. At the same time, find the maximum duration animation.
+    dur_max = add_obj(fid, objs, 1, p_scale)
 
-    # Add progress bar.
+    # Add a progress bar.
     if progress:
         stroke = x_span*0.01
         sbar = shape([-0.5, 0.5], [0.0, 0.0], stroke=stroke, alpha=0.1)
@@ -173,7 +244,7 @@ def animate(obj, filename='ani.svg', x_lim=None, y_lim=None, width=None,
         y = -(py_span + py_top)/p_scale + 0.25*stroke
         fbar = frame(sbar, x=[xa, xb], y=y,
                 scale=[0.01*x_span, x_span], dur=dur_max)
-        add_obj(fid, fbar, level, p_scale)
+        add_obj(fid, fbar, 1, p_scale)
 
     # Close the file.
     fid.write('\n</svg>')
@@ -205,11 +276,29 @@ def add_obj(fid, obj, level, p_scale):
     -----
     If the object is a list, call this function on each of the members.
 
-    If the object is a frame, create an group, specify any static translate,
-    rotate, or scale properties, add the child objects, add any dynamic
-    (animated) translate, rotate, or scale properties, and close the group.
+    If the object is a frame, create a group, specify any static properties, add
+    the child objects, add any dynamic (animated) properties, and close the
+    group.
 
-    If the object is a shape, add the shape.
+    Similarly, if the object is a shape, create the shape, specify any static
+    properties, specify the path, add any dynamic properties, and close the
+    shape. If the path has no dynamic properties, close the shape with "/>".
+    Otherwise, soft close with ">" and then hard close after the dynamic
+    properties with "</path>" or "</circle>" or "</ellipse>".
+
+    Here is a template::
+
+        <g
+          {static parameters}
+          >
+          <path/circle/ellipse
+            {static parameters}
+            d="{path}"/r="{radius}"/rx="{x axis}" ry="{y axis}"
+            >
+            {dynamic parameters}
+          </path>
+          {dynamic parameters}
+        </g>
     """
 
     # Get the indent string.
@@ -223,14 +312,41 @@ def add_obj(fid, obj, level, p_scale):
             dur = add_obj(fid, child, level, p_scale)
             if dur > dur_max:
                 dur_max = dur
-    elif isinstance(obj, frame):
-        # Open the group.
-        fid.write('\n%s<g' % (ind))
+    else:
+        # Open the object.
+        if isinstance(obj, frame):
+            fid.write('\n%s<g' % (ind))
+        elif isinstance(obj, shape):
+            x_scalar = isinstance(obj.sx, (float, int))
+            ind = '  '*level
+            if x_scalar:
+                if abs(obj.sx - obj.sy) < 1e-6:
+                    fid.write('\n%s<circle' % (ind))
+                    rs = '0' if abs(obj.sx*p_scale) < 1e-3 else \
+                            "%.3f" % (abs(obj.sx*p_scale))
+                    fid.write('\n%s  r=\"%s\"' % (ind, rs))
+                else:
+                    fid.write('\n%s<ellipse' % (ind))
+                    xs = '0' if abs(obj.sx*p_scale) < 1e-3 else \
+                            "%.3f" % (abs(obj.sx*p_scale))
+                    ys = '0' if abs(obj.sy*p_scale) < 1e-3 else \
+                            "%.3f" % (abs(obj.sy*p_scale))
+                    fid.write('\n%s  rx=\"%.3f\" ry=\"%.3f\"' % (ind, xs, ys))
+            else:
+                fid.write('\n%s<path' % (ind))
 
         # Get static flags.
         trans_static = isinstance(obj.x, (float, int))
         rot_static = isinstance(obj.ang, (float, int))
         scale_static = isinstance(obj.scale, (float, int))
+        stroke_static = isinstance(obj.stroke, (float, int))
+        color_static = isinstance(obj.color, (float, int))
+        alpha_static = isinstance(obj.alpha, (float, int))
+        if trans_static and rot_static and scale_static and \
+                stroke_static and color_static and alpha_static:
+            all_static = True
+        else:
+            all_static = False
 
         # Get non-trivial flags.
         trans_nontrivial = True if not trans_static else \
@@ -239,36 +355,98 @@ def add_obj(fid, obj, level, p_scale):
                 (abs(obj.ang) > 1e-6)
         scale_nontrivial = True if not scale_static else \
                 (abs(obj.scale - 1.0) > 1e-6)
+        stroke_nontrivial = True if not stroke_static else \
+                (abs(obj.stroke) > 1e-6)
+        color_nontrivial = True if not color_static else \
+                (abs(obj.color) > 0x000000)
+        alpha_nontrivial = True if not alpha_static else \
+                (abs(obj.alpha - 1) > 1e-6)
 
-        # Write any static, non-trivial properties.  Static rotation should
-        # be handled here only if translation is also static.  If there is
+        # Write any static, non-trivial properties. Static rotation should
+        # be handled here only if translation is also static. If there is
         # dynamic translation, the static rotation should be handled by the
-        # dynamic rotation so that rotation always comes before translation.
+        # dynamic rotation so that rotation always occurs before translation.
         if (trans_static and trans_nontrivial) or \
                 (trans_static and rot_static and rot_nontrivial) or \
                 (scale_static and scale_nontrivial):
-            fid.write(' transform=\"')
+            fid.write('\n%s  transform=\"' % (ind))
+            sep = ''
             if trans_static and trans_nontrivial:
                 xs = '0' if abs(obj.x*p_scale) < 1e-3 else \
                         "%.3f" % (obj.x*p_scale)
                 ys = '0' if abs(obj.y*p_scale) < 1e-3 else \
                         "%.3f" % (-obj.y*p_scale)
-                fid.write(' translate(%s,%s)' % (xs, ys))
+                fid.write('%stranslate(%s,%s)' % (sep, xs, ys))
+                sep = ' '
             if trans_static and rot_static and rot_nontrivial:
                 angs = '0' if abs(obj.ang) < 1e-3 else "%.3f" % (-obj.ang)
-                fid.write(' rotate(%s)' % (angs))
+                fid.write('%srotate(%s)' % (sep, angs))
+                sep = ' '
             if scale_static and scale_nontrivial:
                 ss = '0' if abs(obj.scale*p_scale) < 1e-3 else \
                         "%.3f" % (obj.scale*p_scale)
-                fid.write(' scale(%s)' % (ss))
+                fid.write('%sscale(%s)' % (sep, ss))
             fid.write('\"')
-        fid.write('>')
+        if stroke_static and (abs(obj.stroke) <= 1e-6):
+            fid.write('\n%s  fill=\"#%s\"' % (ind, hex(obj.color)[2:].zfill(6)))
+        else:
+            if not isinstance(obj, frame):
+                fid.write('\n%s  vector-effect=\"non-scaling-stroke\"' % (ind))
+            fid.write('\n%s  fill-opacity=\"0\"' % (ind))
+            fid.write('\n%s  stroke-linecap=\"round\"' % (ind))
+            fid.write('\n%s  stroke-linejoin=\"round\"' % (ind))
+            if stroke_static:
+                ss = '0' if abs(obj.stroke*p_scale) < 1e-3 else \
+                        "%.3f" % (obj.stroke*p_scale)
+                fid.write('\n%s  stroke-width=\"%s\"' % (ind, ss))
+            if color_static:
+                fid.write('\n%s  stroke=\"#%s\"' %
+                        (ind, hex(obj.color)[2:].zfill(6)))
+        if alpha_nontrivial:
+            if alpha_static:
+                alphas = '0' if abs(obj.alpha) < 1e-3 else "%.3f" % (obj.alpha)
+            else:
+                alphas = '%.3f' % (obj.alpha[0])
+            fid.write('\n%s  opacity=\"%s\"' % (ind, alphas))
 
-        # Add the objects in this group.
-        for child in obj.objs:
-            dur = add_obj(fid, child, level + 1, p_scale)
-            if dur > dur_max:
-                dur_max = dur
+        # Close group static parameters.
+        if isinstance(obj, frame):
+            fid.write('\n%s  >' % (ins))
+        elif isinstance(obj, shape):
+            if all_static:
+                fid.write('\n%s  />' % (ins)) # hard close
+            else:
+                fid.write('\n%s  >' % (ins)) # soft close
+
+        # Add the body of this object.
+        if isinstance(obj, frame):
+            # Add children of the frame.
+            for child in obj.objs:
+                dur = add_obj(fid, child, level + 1, p_scale)
+                if dur > dur_max:
+                    dur_max = dur
+        elif isinstance(obj, shape) and not x_scalar:
+            # Get key points in (sx,sy) path.
+            px = [ x_n*p_scale for x_n in obj.sx]
+            py = [-y_n*p_scale for y_n in obj.sy]
+            nx_keys = keypoints(px, 0.2)
+            ny_keys = keypoints(py, 0.2)
+            nn_keys = sorted(list(set(nx_keys).union(set(ny_keys))))
+            px = [px[n] for n in nn_keys]
+            py = [py[n] for n in nn_keys]
+            # Write points.
+            txt = '\n%s  d=\"M %.3f,%.3f L' % \
+                    (ind, px[0], py[0])
+            for n in range(1, len(px)):
+                txt_new = '%.3f,%.3f' % (px[n], py[n])
+                if len(txt) + 1 + len(txt_new) >= 80:
+                    fid.write(txt + '\n')
+                    txt = ind + '   '
+                txt += ' ' + txt_new
+            if do_fill:
+                txt += ' z'
+            txt += '\"'
+            fid.write(txt)
 
         # Add dynamic settings.
         if not trans_static:
@@ -283,19 +461,18 @@ def add_obj(fid, obj, level, p_scale):
         if obj.dur > dur_max:
             dur_max = obj.dur
 
-        # Close the group.
-        fid.write('\n%s</g>' % (ind))
-    elif isinstance(obj, shape):
-        add_shape(fid, obj, level, p_scale)
-        if obj.dur > dur_max:
-            dur_max = obj.dur
+        # Close the shape or group.
+        if isinstance(obj, shape):
+            fid.write('\n%s  />' % (ind))
+        elif isinstance(obj, frame):
+            fid.write('\n%s</g>' % (ind))
 
     return dur_max
 
 
 def add_shape(fid, obj, level, p_scale):
     """
-    Add shape object details: the shape itself as defined by (`x`,`y`),
+    Add shape object details: the shape itself as defined by (`sx`,`sy`),
     `stroke` width, stroke or fill `color`, and `alpha`.
 
     Parameters
@@ -311,11 +488,11 @@ def add_shape(fid, obj, level, p_scale):
 
     Notes
     -----
-    First, the type of shape needs to be determined.  If (`x`,`y`) is a
+    First, the type of shape needs to be determined. If (`sx`,`sy`) is a
     single pair of scalar values, then this is either a circle or and
-    ellipse where `x` is the x-axis radius and `y` is the y-axis radius.  If
-    `x` equals `y` then it is a circle, and if not, then it is an ellipse.
-    If (`x`,`y`) is a pair of vectors, then a generic path is created.
+    ellipse where `sx` is the sx-axis radius and `y` is the y-axis radius. If
+    `sx` equals `sy` then it is a circle, and if not, then it is an ellipse.
+    If (`sx`,`sy`) is a pair of vectors, then a generic path is created.
 
     Second, any static properties of the shape are specified.
 
@@ -325,7 +502,7 @@ def add_shape(fid, obj, level, p_scale):
     """
 
     # Get static flags.
-    x_scalar = isinstance(obj.x, (float, int))
+    x_scalar = isinstance(obj.sx, (float, int))
     stroke_static = isinstance(obj.stroke, (float, int))
     color_static = isinstance(obj.color, (float, int))
     alpha_static = isinstance(obj.alpha, (float, int))
@@ -339,17 +516,17 @@ def add_shape(fid, obj, level, p_scale):
     # Open the shape.
     ind = '  '*level
     if x_scalar:
-        if abs(obj.x - obj.y) < 1e-6:
+        if abs(obj.sx - obj.sy) < 1e-6:
             fid.write('\n%s<circle' % (ind))
-            rs = '0' if abs(obj.x*p_scale) < 1e-3 else \
-                    "%.3f" % (abs(obj.x*p_scale))
+            rs = '0' if abs(obj.sx*p_scale) < 1e-3 else \
+                    "%.3f" % (abs(obj.sx*p_scale))
             fid.write('\n%s  r=\"%s\"' % (ind, rs))
         else:
             fid.write('\n%s<ellipse' % (ind))
-            xs = '0' if abs(obj.x*p_scale) < 1e-3 else \
-                    "%.3f" % (abs(obj.x*p_scale))
-            ys = '0' if abs(obj.y*p_scale) < 1e-3 else \
-                    "%.3f" % (abs(obj.y*p_scale))
+            xs = '0' if abs(obj.sx*p_scale) < 1e-3 else \
+                    "%.3f" % (abs(obj.sx*p_scale))
+            ys = '0' if abs(obj.sy*p_scale) < 1e-3 else \
+                    "%.3f" % (abs(obj.sy*p_scale))
             fid.write('\n%s  rx=\"%.3f\" ry=\"%.3f\"' % (ind, xs, ys))
     else:
         fid.write('\n%s<path' % (ind))
@@ -373,15 +550,18 @@ def add_shape(fid, obj, level, p_scale):
         if color_static:
             fid.write('\n%s  stroke=\"#%s\"' %
                     (ind, hex(obj.color)[2:].zfill(6)))
-    if alpha_static and alpha_nontrivial:
-        alphas = '0' if abs(obj.alpha) < 1e-3 else "%.3f" % (obj.alpha)
+    if alpha_nontrivial:
+        if alpha_static:
+            alphas = '0' if abs(obj.alpha) < 1e-3 else "%.3f" % (obj.alpha)
+        else:
+            alphas = "%.3f" % (obj.alpha[0])
         fid.write('\n%s  opacity=\"%s\"' % (ind, alphas))
 
     # Write the x and y values.
     if not x_scalar:
-        # Get keypoints in (x,y) path.
-        px = [ x_n*p_scale for x_n in obj.x]
-        py = [-y_n*p_scale for y_n in obj.y]
+        # Get keypoints in (sx,sy) path.
+        px = [ x_n*p_scale for x_n in obj.sx]
+        py = [-y_n*p_scale for y_n in obj.sy]
         nx_keys = keypoints(px, 0.2)
         ny_keys = keypoints(py, 0.2)
         nn_keys = sorted(list(set(nx_keys).union(set(ny_keys))))
@@ -413,7 +593,7 @@ def add_shape(fid, obj, level, p_scale):
         if not alpha_static:
             dynamic_alpha(fid, obj, level + 1)
         if x_scalar:
-            if obj.x == obj.y:
+            if obj.sx == obj.sy:
                 fid.write('\n%s</circle>' % (ind))
             else:
                 fid.write('\n%s</ellipse>' % (ind))
@@ -462,7 +642,7 @@ def dynamic_stroke(fid, obj, level, p_scale):
 
 def dynamic_color(fid, obj, level):
     """
-    Add stroke or fill color animation.  Which is determined by the `stroke`
+    Add stroke or fill color animation. Which is determined by the `stroke`
     value.
 
     Parameters
@@ -544,7 +724,7 @@ def dynamic_alpha(fid, obj, level):
 
     # Get the scaled animation values and key-point indices.
     alphas = obj.alpha.copy()
-    nn_keys = keypoints(alphas, 0.1)
+    nn_keys = keypoints(alphas, 0.01)
 
     # Write the values at key points or write all the values.
     if len(nn_keys) < len(alphas)/2:
@@ -630,8 +810,8 @@ def dynamic_rotate(fid, obj, level):
     Although this is meant for dynamic rotation only, if there is also
     dynamic translation, a static rotation cannot be performed in the group
     opening instructions because that will cause the rotation to occur after
-    the translation.  We always want the rotation to occur before the
-    translation.  So, only this dynamic also handles some static cases.
+    the translation. We always want the rotation to occur before the
+    translation. So, only this dynamic also handles some static cases.
     """
 
     # Skip if the duration is zero.
@@ -703,7 +883,7 @@ def dynamic_scale(fid, obj, level):
     fid.write('\n%s  repeatCount=\"indefinite\"' % (ind))
     fid.write('\n%s  dur=\"%.3fs\"' % (ind, obj.dur))
 
-    # Get the scaled animation values and key-point indices.  This does not need
+    # Get the scaled animation values and key-point indices. This does not need
     # the additional `p_scale` because the shape being scaled dynamically will
     # have already been scaled statically in its coordinates by `p_scale`.
     scales = obj.scale.copy()
